14.106. cdist-type__postfix_postmap(7) — cdist 4.8.1 documentation

# 14.106. cdist-type__postfix_postmap(7)

## 14.106.1. NAME

cdist-type__postfix_postmap - Run postmap on the given file

## 14.106.2. DESCRIPTION

This space intentionally left blank.

## 14.106.3. REQUIRED PARAMETERS

None.

## 14.106.4. OPTIONAL PARAMETERS

None.

## 14.106.5. EXAMPLES

    __postfix_postmap /etc/postfix/generic

## 14.106.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 14.106.7. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.